==> zio-apache-arrow-datafusion_3-0.0.2-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"zio-apache-arrow-datafusion","t":"zio-apache-arrow-datafusion","d":"","k":"static","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion.html#","e":false,"i":"","n":"me.mnedokushev.zio.apache.arrow.datafusion","t":"me.mnedokushev.zio.apache.arrow.datafusion","d":"","k":"package","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context.html#","e":false,"i":"","n":"Context","t":"Context(underlying: SessionContext)","d":"me.mnedokushev.zio.apache.arrow.datafusion","k":"class","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context.html#registerCsv-3fc","e":false,"i":"","n":"registerCsv","t":"registerCsv(name: String, path: Path): Task[Unit]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Context","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context.html#registerParquet-3fc","e":false,"i":"","n":"registerParquet","t":"registerParquet(name: String, path: Path): Task[Unit]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Context","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context.html#sql-92d","e":false,"i":"","n":"sql","t":"sql(query: String): Task[Dataframe]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Context","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context$.html#","e":false,"i":"","n":"Context","t":"Context","d":"me.mnedokushev.zio.apache.arrow.datafusion","k":"object","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context$.html#create-0","e":false,"i":"","n":"create","t":"create: TaskLayer[Context]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Context","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Dataframe.html#","e":false,"i":"","n":"Dataframe","t":"Dataframe(underlying: DataFrame)","d":"me.mnedokushev.zio.apache.arrow.datafusion","k":"class","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Dataframe.html#collect-332","e":false,"i":"","n":"collect","t":"collect[A](implicit schema: Schema[A], decoder: VectorSchemaRootDecoder[A]): ZStream[BufferAllocator, Throwable, A]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Dataframe","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Dataframe.html#show-0","e":false,"i":"","n":"show","t":"show: Task[Unit]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Dataframe","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Dataframe.html#writeCsv-ec1","e":false,"i":"","n":"writeCsv","t":"writeCsv(path: Path): Task[Unit]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Dataframe","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Dataframe.html#writeParquet-ec1","e":false,"i":"","n":"writeParquet","t":"writeParquet(path: Path): Task[Unit]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Dataframe","k":"def","x":""}];

==> zio-apache-arrow-datafusion_3-0.1.8-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"zio-apache-arrow-datafusion","t":"zio-apache-arrow-datafusion","d":"","k":"static","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion.html#","e":false,"i":"","n":"me.mnedokushev.zio.apache.arrow.datafusion","t":"me.mnedokushev.zio.apache.arrow.datafusion","d":"","k":"package","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context.html#","e":false,"i":"","n":"Context","t":"Context(underlying: SessionContext)","d":"me.mnedokushev.zio.apache.arrow.datafusion","k":"class","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context.html#registerCsv-3fc","e":false,"i":"","n":"registerCsv","t":"registerCsv(name: String, path: Path): Task[Unit]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Context","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context.html#registerParquet-3fc","e":false,"i":"","n":"registerParquet","t":"registerParquet(name: String, path: Path): Task[Unit]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Context","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context.html#sql-92d","e":false,"i":"","n":"sql","t":"sql(query: String): Task[Dataframe]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Context","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context$.html#","e":false,"i":"","n":"Context","t":"Context","d":"me.mnedokushev.zio.apache.arrow.datafusion","k":"object","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Context$.html#create-0","e":false,"i":"","n":"create","t":"create: TaskLayer[Context]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Context","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Dataframe.html#","e":false,"i":"","n":"Dataframe","t":"Dataframe(underlying: DataFrame)","d":"me.mnedokushev.zio.apache.arrow.datafusion","k":"class","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Dataframe.html#collect-fffff398","e":false,"i":"","n":"collect","t":"collect[A : SchemaEncoder](implicit evidence$1: Schema[A], evidence$2: SchemaEncoder[A], decoder: VectorSchemaRootDecoder[A]): ZStream[BufferAllocator, Throwable, A]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Dataframe","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Dataframe.html#show-0","e":false,"i":"","n":"show","t":"show: Task[Unit]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Dataframe","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Dataframe.html#writeCsv-ec1","e":false,"i":"","n":"writeCsv","t":"writeCsv(path: Path): Task[Unit]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Dataframe","k":"def","x":""},
{"l":"me/mnedokushev/zio/apache/arrow/datafusion/Dataframe.html#writeParquet-ec1","e":false,"i":"","n":"writeParquet","t":"writeParquet(path: Path): Task[Unit]","d":"me.mnedokushev.zio.apache.arrow.datafusion.Dataframe","k":"def","x":""}];
